summaryrefslogtreecommitdiff
path: root/src/com/android/loganalysis/parser/LogcatParser.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/loganalysis/parser/LogcatParser.java')
-rw-r--r--src/com/android/loganalysis/parser/LogcatParser.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/com/android/loganalysis/parser/LogcatParser.java b/src/com/android/loganalysis/parser/LogcatParser.java
index 3c0f774..f64936c 100644
--- a/src/com/android/loganalysis/parser/LogcatParser.java
+++ b/src/com/android/loganalysis/parser/LogcatParser.java
@@ -274,13 +274,13 @@ public class LogcatParser implements IParser {
data.mLines.add(msg);
}
// Native crashes are separated either by different PID/TIDs or when NativeCrashParser.START
// matches a line. The newest entry is kept in the dataMap for quick lookup while all
// entries are added to the list.
if (anyNativeCrashTagMatches(level, tag)) {
String key = encodeLine(pid, tid, level, tag);
LogcatData data;
- if (!mDataMap.containsKey(key) || NativeCrashParser.START.matcher(msg).matches()) {
+ if (!mDataMap.containsKey(key) || NativeCrashParser.FINGERPRINT.matcher(msg).matches()) {
data = new LogcatData(pid, tid, time, level, tag, mPreambleUtil.getLastTail(),
mPreambleUtil.getIdTail(pid));
mDataMap.put(key, data);
@@ -274,13 +274,13 @@ public class LogcatParser implements IParser {
data.mLines.add(msg);
}
- // Native crashes are separated either by different PID/TIDs or when NativeCrashParser.START
- // matches a line. The newest entry is kept in the dataMap for quick lookup while all
- // entries are added to the list.
+ // Native crashes are separated either by different PID/TIDs or when
+ // NativeCrashParser.FINGERPRINT matches a line. The newest entry is kept in the dataMap
+ // for quick lookup while all entries are added to the list.
if (anyNativeCrashTagMatches(level, tag)) {
String key = encodeLine(pid, tid, level, tag);